API Reference — CGDAT 2.0.3-3-g9aff488 documentation

# API Reference

## Modules

`cgdat.qt_custom` | This package contains all the additional classes and functions that are used in the CGDAT data anaylsis tool.
`cgdat.qt_ui` | This package contains all the QT python classes that were autogenearted out of the .ui files by the PyQt5.uic.pyuic module.

## Functions

`cgdat.cgdat` | This file contains the main GUI class that is used in the Conditional game data analyse tool (CGDAT) was created for a friend of mine to help him with the data analysis he had to do for his graduation project.
`cgdat.create_shortcut_cl` | This function creates a shortcut which can be used to run the CGDAT tool
`cgdat.start_cl` | This script is used to starts the cgdat gui out of the command line

## Scripts

`start_cgdat` | This script is used to strat the cgdat gui out of the command line
`install_cgdat` | Python function used to install the CGDAT package, its dependencies and create a shortcut.
`create_shortcut_cl` | This function creates a shortcut which can be used to run the CGDAT tool